@@ -26,7 +26,9 @@ tesseract_download <- function(lang, datapath = NULL, progress = TRUE){
   }
   stopifnot(is.character(lang))
   stopifnot(is.character(datapath))
-  url <- sprintf('https://github.com/tesseract-ocr/tessdata/raw/3.04.00/%s.traineddata', lang)
+  version <- as.numeric(substring(tesseract_config()$version, 1, 4))
+  branch <- ifelse(version < 4, "3.04.00", "4.00")
+  url <- sprintf('https://github.com/tesseract-ocr/tessdata/raw/%s/%s.traineddata', branch, lang)
   req <- curl::curl_fetch_memory(url, curl::new_handle(
     noprogress = !isTRUE(progress),
     progressfunction = progress_fun
